pub struct HasEndedResponse {
pub has_ended: bool,
}Fields
has_ended: boolTrait Implementations
Sourceimpl Clone for HasEndedResponse
impl Clone for HasEndedResponse
Sourcefn clone(&self) -> HasEndedResponse
fn clone(&self) -> HasEndedResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HasEndedResponse
impl Debug for HasEndedResponse
Sourceimpl<'de> Deserialize<'de> for HasEndedResponse
impl<'de> Deserialize<'de> for HasEndedResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HasEndedResponse
impl JsonSchema for HasEndedResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HasEndedResponse
impl PartialEq for HasEndedResponse
Sourceimpl Serialize for HasEndedResponse
impl Serialize for HasEndedResponse
impl StructuralPartialEq for HasEndedResponse